==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/netapp/kotlin/inputs/LdapSearchScopeOptArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.netapp.kotlin.inputs

import com.pulumi.azurenative.netapp.inputs.LdapSearchScopeOptArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * LDAP search scope
 * @property groupDN This specifies the group DN, which overrides the base DN for group lookups.
 * @property groupMembershipFilter This specifies the custom LDAP search filter to be used when looking up group membership from LDAP server.
 * @property userDN This specifies the user DN, which overrides the base DN for user lookups.
 */
public data class LdapSearchScopeOptArgs(
    public val groupDN: Output<String>? = null,
    public val groupMembershipFilter: Output<String>? = null,
    public val userDN: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.netapp.inputs.LdapSearchScopeOptArgs> {
    override fun toJava(): com.pulumi.azurenative.netapp.inputs.LdapSearchScopeOptArgs =
        com.pulumi.azurenative.netapp.inputs.LdapSearchScopeOptArgs.builder()
            .groupDN(groupDN?.applyValue({ args0 -> args0 }))
            .groupMembershipFilter(groupMembershipFilter?.applyValue({ args0 -> args0 }))
            .userDN(userDN?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LdapSearchScopeOptArgs].
 */
@PulumiTagMarker
public class LdapSearchScopeOptArgsBuilder internal constructor() {
    private var groupDN: Output<String>? = null

    private var groupMembershipFilter: Output<String>? = null

    private var userDN: Output<String>? = null

    /**
     * @param value This specifies the group DN, which overrides the base DN for group lookups.
     */
    @JvmName("bpqncuhaekmsqoxe")
    public suspend fun groupDN(`value`: Output<String>) {
        this.groupDN = value
    }

    /**
     * @param value This specifies the custom LDAP search filter to be used when looking up group membership from LDAP server.
     */
    @JvmName("fitvhqujqoqskxdj")
    public suspend fun groupMembershipFilter(`value`: Output<String>) {
        this.groupMembershipFilter = value
    }

    /**
     * @param value This specifies the user DN, which overrides the base DN for user lookups.
     */
    @JvmName("ajcyugqyyquyptaf")
    public suspend fun userDN(`value`: Output<String>) {
        this.userDN = value
    }

    /**
     * @param value This specifies the group DN, which overrides the base DN for group lookups.
     */
    @JvmName("untdvdeagefndgky")
    public suspend fun groupDN(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupDN = mapped
    }

    /**
     * @param value This specifies the custom LDAP search filter to be used when looking up group membership from LDAP server.
     */
    @JvmName("avleohqjogtxuwxi")
    public suspend fun groupMembershipFilter(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupMembershipFilter = mapped
    }

    /**
     * @param value This specifies the user DN, which overrides the base DN for user lookups.
     */
    @JvmName("uegbyiekpfcdgfps")
    public suspend fun userDN(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userDN = mapped
    }

    internal fun build(): LdapSearchScopeOptArgs = LdapSearchScopeOptArgs(
        groupDN = groupDN,
        groupMembershipFilter = groupMembershipFilter,
        userDN = userDN,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/netapp/kotlin/inputs/LdapSearchScopeOptArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.netapp.kotlin.inputs

import com.pulumi.azurenative.netapp.inputs.LdapSearchScopeOptArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * LDAP search scope
 * @property groupDN This specifies the group DN, which overrides the base DN for group lookups.
 * @property groupMembershipFilter This specifies the custom LDAP search filter to be used when looking up group membership from LDAP server.
 * @property userDN This specifies the user DN, which overrides the base DN for user lookups.
 */
public data class LdapSearchScopeOptArgs(
    public val groupDN: Output<String>? = null,
    public val groupMembershipFilter: Output<String>? = null,
    public val userDN: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.netapp.inputs.LdapSearchScopeOptArgs> {
    override fun toJava(): com.pulumi.azurenative.netapp.inputs.LdapSearchScopeOptArgs =
        com.pulumi.azurenative.netapp.inputs.LdapSearchScopeOptArgs.builder()
            .groupDN(groupDN?.applyValue({ args0 -> args0 }))
            .groupMembershipFilter(groupMembershipFilter?.applyValue({ args0 -> args0 }))
            .userDN(userDN?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LdapSearchScopeOptArgs].
 */
@PulumiTagMarker
public class LdapSearchScopeOptArgsBuilder internal constructor() {
    private var groupDN: Output<String>? = null

    private var groupMembershipFilter: Output<String>? = null

    private var userDN: Output<String>? = null

    /**
     * @param value This specifies the group DN, which overrides the base DN for group lookups.
     */
    @JvmName("uwlmjdfqyisqmrxt")
    public suspend fun groupDN(`value`: Output<String>) {
        this.groupDN = value
    }

    /**
     * @param value This specifies the custom LDAP search filter to be used when looking up group membership from LDAP server.
     */
    @JvmName("pfqsbmtksdsxufka")
    public suspend fun groupMembershipFilter(`value`: Output<String>) {
        this.groupMembershipFilter = value
    }

    /**
     * @param value This specifies the user DN, which overrides the base DN for user lookups.
     */
    @JvmName("aqxpmvpqgkeevxps")
    public suspend fun userDN(`value`: Output<String>) {
        this.userDN = value
    }

    /**
     * @param value This specifies the group DN, which overrides the base DN for group lookups.
     */
    @JvmName("buxlbbaxqriuttch")
    public suspend fun groupDN(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupDN = mapped
    }

    /**
     * @param value This specifies the custom LDAP search filter to be used when looking up group membership from LDAP server.
     */
    @JvmName("ytuyfuydsfepchta")
    public suspend fun groupMembershipFilter(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupMembershipFilter = mapped
    }

    /**
     * @param value This specifies the user DN, which overrides the base DN for user lookups.
     */
    @JvmName("buajployqufgctvw")
    public suspend fun userDN(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userDN = mapped
    }

    internal fun build(): LdapSearchScopeOptArgs = LdapSearchScopeOptArgs(
        groupDN = groupDN,
        groupMembershipFilter = groupMembershipFilter,
        userDN = userDN,
    )
}
